==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/pt-BR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuário pode efetuar login',
    'activated_disabled_help_text' => 'Você não pode alterar o status de ativação da sua própria conta.',
    'assets_user'       => 'Bens atribuidos a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Por favor, note que você não pode alterar seus próprios atributos de usuário usando este formulário e deve fazer edições de seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado.',
    'current_assets'    => 'Artivos atribuídos atualmente a este usuário',
    'clone'             => 'Clonar Usuário',
    'contact_user'      => 'Contato :name',
    'edit'              => 'Editar Usuário',
    'filetype_info'     => 'Tipo de arquivos permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Histórico para :name',
    'info'				=> 'Informações',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último Login',
    'ldap_config_text'  => 'As configurações do LDAP podem ser encontradas em \'Administrador > Definições\'. A localização (opcional) selecionada será definida para todos os usuários importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'email_assigned'    => 'Lista de e-mails de todos os atribuídos',
    'user_notified'     => 'Um usuário recebeu um e-mail com uma lista de seus itens atualmente atribuídos.',
    'auto_assign_label' => 'Inclua este usuário quando atribuir licenças elegíveis automaticamente',
    'auto_assign_help'  => 'Ignorar este usuário em atribuição automática de licenças',
    'software_user'     => 'Check-out de software para :name',
    'send_email_help'   => 'Você deve fornecer um endereço de e-mail para este usuário enviar credenciais. As credenciais de e-mail só podem ser feitas na criação do usuário. As senhas são armazenadas em hash unidirecional e não podem ser recuperadas uma vez salva.',
    'view_user'         => 'Ver Usuário :name',
    'usercsv'           => 'Arquivo CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin atuais permitem a aplicação seletiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Registrado ',
    'two_factor_active'   => '2FA Ativo ',
    'user_deactivated'  => 'O usuário não pode acessar',
    'user_activated'  => 'Usuário pode efetuar login',
    'activation_status_warning' => 'Não alterar o status de ativação',
    'group_memberships_helpblock' => 'Somente superadministradores podem editar associações de grupo.',
    'superadmin_permission_warning' => 'Somente superadministradores podem conceder acesso de superadministrador ao usuário.',
    'admin_permission_warning' => 'Somente usuários com direitos de administrador ou maiores podem conceder acesso de administrador ao usuário.',
    'remove_group_memberships' => 'Remover Associações de Grupo',
    'warning_deletion_information' => 'Você está prestes a check-in TODOS os itens do(s) :count usuário(s) listado(s) abaixo. Nomes de Super admin são destacados em vermelho.',
    'update_user_assets_status' => 'Atualizar todos os arquivos para esses usuários com este status',
    'checkin_user_properties' => 'Check-in de todas as propriedades associadas a estes usuários',
    'remote_label'   => 'Este é um usuário remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Isso pode ser útil se você precisa filtrar por usuários remotos que nunca entram em seus locais físicos.',
    'not_remote_label' => 'Este não é um usuário remoto',
    'vip_label' => 'Usuário VIP',
    'vip_help' => 'Isso pode ser útil para marcar pessoas importantes na sua organização, se você quiser lidar com elas de formas especiais.',
    'create_user' => 'Criar um usuário',
    'create_user_page_explanation' => 'Esta é a informação de conta que você usará para acessar o site pela primeira vez.',
    'email_credentials' => 'Credenciais do e-mail',
    'email_credentials_text' => 'Enviar minhas credenciais para o endereço de e-mail acima',
    'next_save_user' => 'Próximo: Salvar Usuário',
    'all_assigned_list_generation' => 'Gerado em:',
    'email_user_creds_on_create' => 'Enviar por email suas credenciais?',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/pt-BR/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este usuário pode efetuar login',
    'activated_disabled_help_text' => 'Você não pode alterar a situação de ativação da sua própria conta.',
    'assets_user'       => 'Bens atribuidos a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Por favor, note que você não pode alterar seus próprios atributos de usuário usando este formulário e deve fazer edições de seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado.',
    'current_assets'    => 'Artivos atribuídos atualmente a este usuário',
    'clone'             => 'Clonar Usuário',
    'contact_user'      => 'Contato :name',
    'edit'              => 'Editar Usuário',
    'filetype_info'     => 'Tipo de arquivos permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Histórico para :name',
    'info'				=> 'Informações',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último Login',
    'ldap_config_text'  => 'As configurações do LDAP podem ser encontradas em \'Administrador > Definições\'. A localização (opcional) selecionada será definida para todos os usuários importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'email_assigned'    => 'Lista de e-mails de todos os atribuídos',
    'user_notified'     => 'Um usuário recebeu um e-mail com uma lista de seus itens atualmente atribuídos.',
    'auto_assign_label' => 'Inclua este usuário quando atribuir licenças elegíveis automaticamente',
    'auto_assign_help'  => 'Ignorar este usuário em atribuição automática de licenças',
    'software_user'     => 'Disponibilização de software para :name',
    'send_email_help'   => 'Você deve fornecer um endereço de e-mail para este usuário enviar credenciais. As credenciais de e-mail só podem ser feitas na criação do usuário. As senhas são armazenadas em hash unidirecional e não podem ser recuperadas uma vez salva.',
    'view_user'         => 'Ver Usuário :name',
    'usercsv'           => 'Arquivo CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin atuais permitem a aplicação seletiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo 2FA Registrado ',
    'two_factor_active'   => '2FA Ativo ',
    'user_deactivated'  => 'O usuário não pode acessar',
    'user_activated'  => 'Usuário pode efetuar login',
    'activation_status_warning' => 'Não alterar a situação de ativação',
    'group_memberships_helpblock' => 'Somente superadministradores podem editar associações de grupo.',
    'superadmin_permission_warning' => 'Somente superadministradores podem conceder acesso de superadministrador ao usuário.',
    'admin_permission_warning' => 'Somente usuários com direitos de administrador ou maiores podem conceder acesso de administrador ao usuário.',
    'remove_group_memberships' => 'Remover Associações de Grupo',
    'warning_deletion_information' => 'Você está prestes a check-in TODOS os itens do(s) :count usuário(s) listado(s) abaixo. Nomes de Super admin são destacados em vermelho.',
    'update_user_assets_status' => 'Atualizar todos os arquivos para esses usuários com esta situação',
    'checkin_user_properties' => 'Check-in de todas as propriedades associadas a estes usuários',
    'remote_label'   => 'Este é um usuário remoto',
    'remote'   => 'Remoto',
    'remote_help' => 'Isso pode ser útil se você precisa filtrar por usuários remotos que nunca entram em seus locais físicos.',
    'not_remote_label' => 'Este não é um usuário remoto',
    'vip_label' => 'Usuário VIP',
    'vip_help' => 'Isso pode ser útil para marcar pessoas importantes na sua organização, se você quiser lidar com elas de formas especiais.',
    'create_user' => 'Criar um usuário',
    'create_user_page_explanation' => 'Esta é a informação de conta que você usará para acessar o site pela primeira vez.',
    'email_credentials' => 'Credenciais do e-mail',
    'email_credentials_text' => 'Enviar minhas credenciais para o endereço de e-mail acima',
    'next_save_user' => 'Próximo: Salvar Usuário',
    'all_assigned_list_generation' => 'Gerado em:',
    'email_user_creds_on_create' => 'Enviar por email suas credenciais?',
];
